@@ -17,7 +17,7 @@ from typing import (
 from .util import fix_float_single_double_conversion
 
 if TYPE_CHECKING:
-    from .api_pb2 import HomeassistantServiceMap  # type: ignore
+    from .api_pb2 import BluetoothServiceData, HomeassistantServiceMap  # type: ignore
 
 # All fields in here should have defaults set
 # Home Assistant depends on these fields being constructible
@@ -105,6 +105,7 @@ class DeviceInfo(APIModelBase):
     project_name: str = ""
     project_version: str = ""
     webserver_port: int = 0
+    has_bluetooth_proxy: bool = False
 
 
 class EntityCategory(APIIntEnum):
@@ -343,6 +344,7 @@ class SensorStateClass(APIIntEnum):
     NONE = 0
     MEASUREMENT = 1
     TOTAL_INCREASING = 2
+    TOTAL = 3
 
 
 class LastResetType(APIIntEnum):
@@ -653,8 +655,6 @@ class MediaPlayerCommand(APIIntEnum):
 @dataclass(frozen=True)
 class MediaPlayerInfo(EntityInfo):
     supports_pause: bool = False
-    supports_volume: bool = False
-    supports_mute: bool = False
 
 
 @dataclass(frozen=True)
@@ -754,6 +754,51 @@ class UserService(APIModelBase):
     )
 
 
+# ==================== BLUETOOTH ====================
+def _long_uuid(uuid: str) -> str:
+    """Convert a UUID to a long UUID."""
+    return (
+        f"0000{uuid[2:].lower()}-0000-1000-8000-00805f9b34fb" if len(uuid) < 8 else uuid
+    )
+
+
+def _convert_bluetooth_le_service_uuids(value: List[str]) -> List[str]:
+    return [_long_uuid(v) for v in value]
+
+
+def _convert_bluetooth_le_service_data(
+    value: Union[Dict[str, bytes], Iterable["BluetoothServiceData"]],
+) -> Dict[str, bytes]:
+    if isinstance(value, dict):
+        return value
+    return {_long_uuid(v.uuid): bytes(v.data) for v in value}  # type: ignore
+
+
+def _convert_bluetooth_le_manufacturer_data(
+    value: Union[Dict[int, bytes], Iterable["BluetoothServiceData"]],
+) -> Dict[int, bytes]:
+    if isinstance(value, dict):
+        return value
+    return {int(v.uuid, 16): bytes(v.data) for v in value}  # type: ignore
+
+
+@dataclass(frozen=True)
+class BluetoothLEAdvertisement(APIModelBase):
+    address: int = 0
+    name: str = ""
+    rssi: int = 0
+
+    service_uuids: List[str] = converter_field(
+        default_factory=list, converter=_convert_bluetooth_le_service_uuids
+    )
+    service_data: Dict[str, bytes] = converter_field(
+        default_factory=dict, converter=_convert_bluetooth_le_service_data
+    )
+    manufacturer_data: Dict[int, bytes] = converter_field(
+        default_factory=dict, converter=_convert_bluetooth_le_manufacturer_data
+    )
+
+
 class LogLevel(APIIntEnum):
     LOG_LEVEL_NONE = 0
     LOG_LEVEL_ERROR = 1
